# CHANGELOG

<!-- version list -->

## v1.0.0 (2026-02-19)

### Continuous Integration

- Trigger v1.0.0 release
  ([`adaf568`](https://github.com/tlancaster6/AquaKit/commit/adaf56838f09a80fafec6f44edfdb2dc9b711ea5))


## v1.0.0-dev.1 (2026-02-19)

- Initial Release
